@@ -7,10 +7,10 @@
 #define ADIOSCONFIG_H_
 
 /* ADIOS Version Information */
-#define ADIOS2_VERSION_STR   "2.10.2"
+#define ADIOS2_VERSION_STR   "2.11.0"
 #define ADIOS2_VERSION_MAJOR 2
-#define ADIOS2_VERSION_MINOR 10
-#define ADIOS2_VERSION_PATCH 2
+#define ADIOS2_VERSION_MINOR 11
+#define ADIOS2_VERSION_PATCH 0
 /* #undef ADIOS2_VERSION_TWEAK */
 
 #define ADIOS2_VERSION (ADIOS2_VERSION_MAJOR* 10000 + ADIOS2_VERSION_MINOR * 100 + ADIOS2_VERSION_PATCH)
@@ -19,12 +19,12 @@
  * ADIOS Build Information:
  *
  * Compiler:
- *   C: C:/msys64/clangarm64/bin/clang.exe
- *     Id: Clang 19.1.4
- *   CXX: C:/msys64/clangarm64/bin/clang++.exe
- *     Id: Clang 19.1.4
- *   Fortran: C:/msys64/clangarm64/bin/clang++.exe
- *     Id: LLVMFlang 19.1.4
+ *   C: C:/M/msys64/clangarm64/bin/clang.exe
+ *     Id: Clang 21.1.5
+ *   CXX: C:/M/msys64/clangarm64/bin/clang++.exe
+ *     Id: Clang 21.1.5
+ *   Fortran: C:/M/msys64/clangarm64/bin/clang++.exe
+ *     Id: LLVMFlang 21.1.5
  */
 
 /* Everything between here and the note below is programatically generated */
@@ -60,6 +60,9 @@
 /* CMake Option: ADIOS2_USE_PIP=OFF */
 /* #undef ADIOS2_HAVE_PIP */
 
+/* CMake Option: ADIOS2_USE_BigWhoop=OFF */
+/* #undef ADIOS2_HAVE_BIGWHOOP */
+
 /* CMake Option: ADIOS2_USE_Blosc2=OFF */
 #define ADIOS2_HAVE_BLOSC2
 
@@ -118,7 +121,13 @@
 /* #undef ADIOS2_HAVE_DERIVED_VARIABLE */
 
 /* CMake Option: ADIOS2_USE_AWSSDK=OFF */
-/* #undef ADIOS2_HAVE_AWSSDK */
+#define ADIOS2_HAVE_AWSSDK
+
+/* CMake Option: ADIOS2_USE_OpenSSL=OFF */
+#define ADIOS2_HAVE_OPENSSL
+
+/* CMake Option: ADIOS2_USE_XRootD=OFF */
+/* #undef ADIOS2_HAVE_XROOTD */
 
 /* CMake Option: ADIOS2_USE_GPU_Support=OFF */
 /* #undef ADIOS2_HAVE_GPU_SUPPORT */
@@ -141,6 +150,9 @@
 /* CMake Option: ADIOS2_USE_Campaign=OFF */
 #define ADIOS2_HAVE_CAMPAIGN
 
+/* CMake Option: ADIOS2_USE_KVCACHE=OFF */
+/* #undef ADIOS2_HAVE_KVCACHE */
+
 
 /*
  * Constant defines: These are available unconditionally
@@ -151,7 +163,7 @@
 #define ADIOS2_HAVE_BP4
 #define ADIOS2_HAVE_BP5
 
-#define ADIOS2_FEATURE_LIST "BP3" "BP4" "BP5" "HDF5","HDF5_VOL","MHS","FORTRAN","PYTHON","BLOSC2","BZIP2","PNG","SODIUM","ZEROMQ","CAMPAIGN",nullptr
+#define ADIOS2_FEATURE_LIST "BP3" "BP4" "BP5" "HDF5","HDF5_VOL","MHS","FORTRAN","PYTHON","BLOSC2","BZIP2","PNG","SODIUM","ZEROMQ","AWSSDK","OPENSSL","CAMPAIGN",nullptr
 
 /* Everything between here and the note above is programatically generated */
 
